==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ServerFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ServerFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ServerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ServerFluent<A>{
  public ServerFluentImpl() {
  }
  public ServerFluentImpl(io.fabric8.openshift.api.model.operator.v1.Server instance) {
    this.withForwardPlugin(instance.getForwardPlugin()); 
    this.withName(instance.getName()); 
    this.withZones(instance.getZones()); 
  }
  private io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder forwardPlugin;
  private java.lang.String name;
  private java.util.List<java.lang.String> zones = new java.util.ArrayList<java.lang.String>();
  
  /**
   * This method has been deprecated, please use method buildForwardPlugin instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.ForwardPlugin getForwardPlugin() {
    return this.forwardPlugin!=null?this.forwardPlugin.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.ForwardPlugin buildForwardPlugin() {
    return this.forwardPlugin!=null?this.forwardPlugin.build():null;
  }
  public A withForwardPlugin(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin forwardPlugin) {
    _visitables.get("forwardPlugin").remove(this.forwardPlugin);
    if (forwardPlugin!=null){ this.forwardPlugin= new io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder(forwardPlugin); _visitables.get("forwardPlugin").add(this.forwardPlugin);} return (A) this;
  }
  public java.lang.Boolean hasForwardPlugin() {
    return this.forwardPlugin != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> withNewForwardPlugin() {
    return new io.fabric8.openshift.api.model.operator.v1.ServerFluentImpl.ForwardPluginNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> withNewForwardPluginLike(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin item) {
    return new io.fabric8.openshift.api.model.operator.v1.ServerFluentImpl.ForwardPluginNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> editForwardPlugin() {
    return withNewForwardPluginLike(getForwardPlugin());
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> editOrNewForwardPlugin() {
    return withNewForwardPluginLike(getForwardPlugin() != null ? getForwardPlugin(): new io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> editOrNewForwardPluginLike(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin item) {
    return withNewForwardPluginLike(getForwardPlugin() != null ? getForwardPlugin(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToZones(java.lang.Integer index,java.lang.String item) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<java.lang.String>();}
    this.zones.add(index, item);
    return (A)this;
  }
  public A setToZones(java.lang.Integer index,java.lang.String item) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<java.lang.String>();}
    this.zones.set(index, item); return (A)this;
  }
  public A addToZones(java.lang.String... items) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.zones.add(item);} return (A)this;
  }
  public A addAllToZones(java.util.Collection<java.lang.String> items) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.zones.add(item);} return (A)this;
  }
  public A removeFromZones(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.zones!= null){ this.zones.remove(item);}} return (A)this;
  }
  public A removeAllFromZones(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.zones!= null){ this.zones.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getZones() {
    return this.zones;
  }
  public java.lang.String getZone(java.lang.Integer index) {
    return this.zones.get(index);
  }
  public java.lang.String getFirstZone() {
    return this.zones.get(0);
  }
  public java.lang.String getLastZone() {
    return this.zones.get(zones.size() - 1);
  }
  public java.lang.String getMatchingZone(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: zones) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingZone(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: zones) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withZones(java.util.List<java.lang.String> zones) {
    if (zones != null) {this.zones = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : zones){this.addToZones(item);}} else { this.zones = null;} return (A) this;
  }
  public A withZones(java.lang.String... zones) {
    if (this.zones != null) {this.zones.clear();}
    if (zones != null) {for (java.lang.String item :zones){ this.addToZones(item);}} return (A) this;
  }
  public java.lang.Boolean hasZones() {
    return zones != null && !zones.isEmpty();
  }
  public A addNewZone(java.lang.String arg0) {
    return (A)addToZones(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ServerFluentImpl that = (ServerFluentImpl) o;
    if (forwardPlugin != null ? !forwardPlugin.equals(that.forwardPlugin) :that.forwardPlugin != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (zones != null ? !zones.equals(that.zones) :that.zones != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(forwardPlugin,  name,  zones,  super.hashCode());
  }
  public class ForwardPluginNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.ForwardPluginFluentImpl<io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<N>> implements io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ForwardPluginNestedImpl(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder(this, item);
    }
    ForwardPluginNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder builder;
    public N and() {
      return (N) ServerFluentImpl.this.withForwardPlugin(builder.build());
    }
    public N endForwardPlugin() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ServerFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ServerFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ServerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ServerFluent<A>{
  public ServerFluentImpl() {
  }
  public ServerFluentImpl(io.fabric8.openshift.api.model.operator.v1.Server instance) {
    this.withForwardPlugin(instance.getForwardPlugin()); 
    this.withName(instance.getName()); 
    this.withZones(instance.getZones()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder forwardPlugin;
  private java.lang.String name;
  private java.util.List<java.lang.String> zones = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildForwardPlugin instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.ForwardPlugin getForwardPlugin() {
    return this.forwardPlugin!=null?this.forwardPlugin.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.ForwardPlugin buildForwardPlugin() {
    return this.forwardPlugin!=null?this.forwardPlugin.build():null;
  }
  public A withForwardPlugin(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin forwardPlugin) {
    _visitables.get("forwardPlugin").remove(this.forwardPlugin);
    if (forwardPlugin!=null){ this.forwardPlugin= new io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder(forwardPlugin); _visitables.get("forwardPlugin").add(this.forwardPlugin);} return (A) this;
  }
  public java.lang.Boolean hasForwardPlugin() {
    return this.forwardPlugin != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> withNewForwardPlugin() {
    return new io.fabric8.openshift.api.model.operator.v1.ServerFluentImpl.ForwardPluginNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> withNewForwardPluginLike(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin item) {
    return new io.fabric8.openshift.api.model.operator.v1.ServerFluentImpl.ForwardPluginNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> editForwardPlugin() {
    return withNewForwardPluginLike(getForwardPlugin());
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> editOrNewForwardPlugin() {
    return withNewForwardPluginLike(getForwardPlugin() != null ? getForwardPlugin(): new io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<A> editOrNewForwardPluginLike(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin item) {
    return withNewForwardPluginLike(getForwardPlugin() != null ? getForwardPlugin(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToZones(java.lang.Integer index,java.lang.String item) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<java.lang.String>();}
    this.zones.add(index, item);
    return (A)this;
  }
  public A setToZones(java.lang.Integer index,java.lang.String item) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<java.lang.String>();}
    this.zones.set(index, item); return (A)this;
  }
  public A addToZones(java.lang.String... items) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.zones.add(item);} return (A)this;
  }
  public A addAllToZones(java.util.Collection<java.lang.String> items) {
    if (this.zones == null) {this.zones = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.zones.add(item);} return (A)this;
  }
  public A removeFromZones(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.zones!= null){ this.zones.remove(item);}} return (A)this;
  }
  public A removeAllFromZones(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.zones!= null){ this.zones.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getZones() {
    return this.zones;
  }
  public java.lang.String getZone(java.lang.Integer index) {
    return this.zones.get(index);
  }
  public java.lang.String getFirstZone() {
    return this.zones.get(0);
  }
  public java.lang.String getLastZone() {
    return this.zones.get(zones.size() - 1);
  }
  public java.lang.String getMatchingZone(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: zones) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingZone(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: zones) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withZones(java.util.List<java.lang.String> zones) {
    if (zones != null) {this.zones = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : zones){this.addToZones(item);}} else { this.zones = null;} return (A) this;
  }
  public A withZones(java.lang.String... zones) {
    if (this.zones != null) {this.zones.clear();}
    if (zones != null) {for (java.lang.String item :zones){ this.addToZones(item);}} return (A) this;
  }
  public java.lang.Boolean hasZones() {
    return zones != null && !zones.isEmpty();
  }
  public A addNewZone(java.lang.String arg0) {
    return (A)addToZones(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ServerFluentImpl that = (ServerFluentImpl) o;
    if (forwardPlugin != null ? !forwardPlugin.equals(that.forwardPlugin) :that.forwardPlugin != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (zones != null ? !zones.equals(that.zones) :that.zones != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(forwardPlugin,  name,  zones,  additionalProperties,  super.hashCode());
  }
  public class ForwardPluginNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.ForwardPluginFluentImpl<io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<N>> implements io.fabric8.openshift.api.model.operator.v1.ServerFluent.ForwardPluginNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ForwardPluginNestedImpl(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder(this, item);
    }
    ForwardPluginNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.ForwardPluginBuilder builder;
    public N and() {
      return (N) ServerFluentImpl.this.withForwardPlugin(builder.build());
    }
    public N endForwardPlugin() {
      return and();
    }
    
  }
  
}
